pub struct Ds3231<I2C> { /* private fields */ }Expand description
DS3231 Real-Time Clock driver
Implementations
Sourceimpl<I2C, E> Ds3231<I2C>
impl<I2C, E> Ds3231<I2C>
Sourcepub fn set_base_century(&mut self, base_century: u8) -> Result<(), Error<E>>
pub fn set_base_century(&mut self, base_century: u8) -> Result<(), Error<E>>
Sets the base century for year calculations.
The DS3231 stores years as 00-99 in BCD format. This base century determines how those 2-digit years are interpreted as full 4-digit years.
Arguments
base_century- The century to use (e.g., 20 for 2000-2099, 21 for 2100-2199)
Returns
Returns Err(Error::InvalidBaseCentury) if base_century is less than 19.
Examples
// Years 00-99 will be interpreted as 2000-2099
let rtc = Ds3231::new(i2c).with_base_century(20)?;
// Years 00-99 will be interpreted as 2100-2199
let rtc = Ds3231::new(i2c).with_base_century(21)?;Sourcepub fn release_i2c(self) -> I2C
pub fn release_i2c(self) -> I2C
Returns the underlying I2C bus instance, consuming the driver.
This allows the user to reuse the I2C bus for other purposes after the driver is no longer needed.
However, if you are using embedded-hal-bus,
you typically do not need release_i2c.
In that case the crate takes care of the sharing